"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBrowserHydrationEnvService = exports.setDefaultHydratingEnvService = exports.hasDefaultHydrationEnvService = exports.getDefaultHydrationEnvService = void 0;
const retil_source_1 = require("retil-source");
const retil_support_1 = require("retil-support");
// Servers don't do hydrationg, so we don't modify the env at all.
const serverHydratingEnvSource = (0, retil_source_1.constant)({});
const serverHydrationEnvService = [
    serverHydratingEnvSource,
    retil_support_1.noop,
];
const getDefaultHydrationEnvService = () => {
    if (!exports.getDefaultHydrationEnvService.value) {
        const isBrowser = typeof window !== 'undefined';
        exports.getDefaultHydrationEnvService.value = isBrowser
            ? createBrowserHydrationEnvService()
            : serverHydrationEnvService;
    }
    return exports.getDefaultHydrationEnvService.value;
};
exports.getDefaultHydrationEnvService = getDefaultHydrationEnvService;
const hasDefaultHydrationEnvService = () => {
    return !!exports.getDefaultHydrationEnvService.value;
};
exports.hasDefaultHydrationEnvService = hasDefaultHydrationEnvService;
const setDefaultHydratingEnvService = (value) => {
    exports.getDefaultHydrationEnvService.value = value;
};
exports.setDefaultHydratingEnvService = setDefaultHydratingEnvService;
function createBrowserHydrationEnvService(options = {}) {
    const { default: defaultHydrationService, disablePrecache } = options;
    const hasDefault = (0, exports.hasDefaultHydrationEnvService)();
    if (hasDefault && defaultHydrationService) {
        throw new Error('Could not override the default hydration service.');
    }
    const [hydratingSource, setHydrating] = (0, retil_source_1.createStateVector)(disablePrecache ? [true] : [true, false]);
    const hydratingEnvSource = (0, retil_source_1.fuse)((use) => ({
        hydrating: use(hydratingSource),
    }));
    let hasHydrated = false;
    const hydrate = () => {
        if (!hasHydrated) {
            hasHydrated = true;
            setHydrating([false]);
        }
    };
    const service = [hydratingEnvSource, hydrate];
    if (!hasDefault &&
        (defaultHydrationService || defaultHydrationService === undefined)) {
        (0, exports.setDefaultHydratingEnvService)(service);
    }
    return service;
}
exports.createBrowserHydrationEnvService = createBrowserHydrationEnvService;
