import { ReactNode } from 'react';
export interface HydrationProviderProps {
    children: ReactNode;
    isHydrating?: boolean;
    onHydrationDetected: () => void;
}
/**
 * An optional provider that allows for manual control of the hydration state.
 *
 * When not provided, the hydration hooks will instead create and interact with
 * a default global hydration service.
 */
export declare const HydrationProvider: (props: HydrationProviderProps) => JSX.Element;
/**
 * Sets up retil-boundary based hydration detection for your app.
 *
 * This should be called once at the top level of your app, above any
 * <Boundary> components. It'll then caue `useIsHydrating()` to become `false`
 * after the first render of the deepest <Boundary> component.
 */
export declare function useBoundaryHydrater(): void;
/**
 * Returns a function that can be called to manually mark the app as hydrated.
 *
 * When used in conjunction with a `<HydrationProvider>`, this will call the
 * provided `onHydrationDetected` function. Otherwise, it'll call the default
 * hydration service's `hydrate` method.
 */
export declare function useMarkAsHydrated(): () => void;
/**
 * Pulls the latest hydration state from the first available source out of:
 *
 * - React Context (as set by a <HydrationProvider>)
 * - retil-mount's useEnv hook, if hydration state is set on the env
 * - the default hydration env service
 *
 *
 */
export declare function useIsHydrating(): boolean | undefined;
export declare function useHasHydrated(): boolean;
