import { createStateVector, constant, fuse } from 'retil-source';
import { noop } from 'retil-support';
// Servers don't do hydrationg, so we don't modify the env at all.
const serverHydratingEnvSource = constant({});
const serverHydrationEnvService = [
    serverHydratingEnvSource,
    noop,
];
export const getDefaultHydrationEnvService = () => {
    if (!getDefaultHydrationEnvService.value) {
        const isBrowser = typeof window !== 'undefined';
        getDefaultHydrationEnvService.value = isBrowser
            ? createBrowserHydrationEnvService()
            : serverHydrationEnvService;
    }
    return getDefaultHydrationEnvService.value;
};
export const hasDefaultHydrationEnvService = () => {
    return !!getDefaultHydrationEnvService.value;
};
export const setDefaultHydratingEnvService = (value) => {
    getDefaultHydrationEnvService.value = value;
};
export function createBrowserHydrationEnvService(options = {}) {
    const { default: defaultHydrationService, disablePrecache } = options;
    const hasDefault = hasDefaultHydrationEnvService();
    if (hasDefault && defaultHydrationService) {
        throw new Error('Could not override the default hydration service.');
    }
    const [hydratingSource, setHydrating] = createStateVector(disablePrecache ? [true] : [true, false]);
    const hydratingEnvSource = fuse((use) => ({
        hydrating: use(hydratingSource),
    }));
    let hasHydrated = false;
    const hydrate = () => {
        if (!hasHydrated) {
            hasHydrated = true;
            setHydrating([false]);
        }
    };
    const service = [hydratingEnvSource, hydrate];
    if (!hasDefault &&
        (defaultHydrationService || defaultHydrationService === undefined)) {
        setDefaultHydratingEnvService(service);
    }
    return service;
}
